| DEPONS2R | R Documentation |
Methods for analyzing population dynamics and movement tracks simulated using the DEPONS model (v.3.0; https://www.depons.eu), for manipulating input raster files, shipping routes and for analyzing sound propagated from ships.
The classes used in DEPONS2R include:
DeponsTrack movement tracks, read from "RandomPorpoise.XXX.csv" files
DeponsDyn population dynamics data, from "Statistics.XXX.csv" files
DeponsBlockdyn data from "PorpoisePerBlock.XXX.csv" files
DeponsShips data from "ships.json" files or from AIS data
Here the DeponsDyn data include both changes in population size and energetics
through time for the entire landscape, whereas DeponsBlockdyn data include
variations in population size in different parts (or 'blocks') of the landscape.
XXX is the date and time when the simulation was finished.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.