| DeponsBlockdyn-class | R Documentation |
Stores objects containing population size for different parts of the landscape (i.e. different 'blocks')
The dyn slot contains a data frame with the columns 'tick',
which indicates the number of half-hourly time steps since the start of the
simulation; a column 'block' indicating the region of the landscape where
animals were counted, a 'count' column with the number of animals in that block
and tick. The 'real.time' column shows the real-world equivalent to 'tick, i.e.
the time that has passed since 'startday'.
titleCharacter. Name of the object or simulation
landscapeCharacter. Identifier for the landscape used in the DEPONS simulations. The landscapes 'DanTysk', 'Gemini', 'Kattegat', 'North Sea', 'Homogeneous', and 'User defined' are distributed with the DEPONS model.
simtimePOSIXlt object with the date and time when the simulation was
finished. This is read from the name of the imput file.
startdayPOSIXlt object with the first day of the simulation, i.e. the first day in the period that the simulations are intended to represent in the real world.
dynData frame with simulation output.
DeponsBlockdyn-objects are usually read in from csv files produced during DEPONS simulations. These files are named 'PorpoisePerBlock.XXX.csv', where XXX indicates the date and time when the simulation was finished.
plot.DeponsBlockdyn and
read.DeponsBlockdyn.
a.DeponsBlockdyn <- new("DeponsBlockdyn")
a.DeponsBlockdyn
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.