| DeponsShips-class | R Documentation |
Objects containing ship routes and ships
Methods for manipulating, plotting and analyzing ship routes and ship agents used in DEPONS simulations.
titleName of the object (character)
landscapeName of the landscape that the ships occur in (character)
crsCRS object providing the coordinate reference system used; see
CRS for details
routesdata.frame geographic positions of the 'virtual buoys'
that define one or more ship routes that ship agents follow, and the speed
that the ships should use when following this route. They also provide
information about how long ships should use speed zero when reaching a
specific buoy ('i.e. 'pause', measured in minutes). Can be extracted
using the routes function.
shipsdata.frame defining each of the ships occurring in DEPONS
simulations, and the routes they occur on. The data frame includes the variables
'name', 'type', 'length', and 'route'. Info can be extracted using the
ships function.
plot.DeponsShips,
and read.DeponsShips
data(shipdata)
ships(shipdata)[1:10,]
routes(shipdata)
plot(shipdata, col=c("red", "purple", "blue"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.