Learn R Programming

DEPONS2R (version 1.2.6)

porpoisetrack: Simulated porpoise track

Description

An object with five elements: title, landscape, simtime, crs, and tracks. The crs stores information about the map projection used ("+proj=utm +zone=32 +datum=WGS84 +units=m +no_defs"). The tracks element is a list of objects of class SpatialPointsDataFrame, each ofwhich corresponds to one simulated animal. simtime is the simulation date.

Arguments

Format

DeponsTrack

See Also

DeponsTrack-class