View source: R/ships_methods.R
| read.DeponsShips | R Documentation |
Function for reading the json-files that are used for controlling how ship agents behave in DEPONS. Ships move along pre-defined routes in 30-min time steps. The routes are defined by the fix-points provided in the json file, and the geographic projection is assumed to match that of the landscape.
read.DeponsShips(fname, title = "NA", landscape = "NA", crs = as.character(NA))
fname |
Name of the file (character) where ship routes and ships are defined. |
title |
Optional character string with the name of the simulation |
landscape |
Optional character string with the landscape used in the simulation |
crs |
Character, coordinate reference system (map projection) |
Returns an object with the elements title landscape,
crs, routes and ships.
ais.to.DeponsShips, write.DeponsShips
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.